@@ -1,7 +1,7 @@
 #!/bin/sh -eu
 # This file is part of the program FRYSK.
 #
-# Copyright 2005, 2006, 2007, Red Hat Inc.
+# Copyright 2005, 2006, 2007, 2008, Red Hat Inc.
 #
 # FRYSK is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by
@@ -75,8 +75,8 @@ GEN_ARGS="$@"
 while test $# -gt 0
 do
   case "$1" in
-      --cni ) cni=true ; jni=false ;;
-      --jni ) jni=true ; cni=false ;;
+      --cni ) cni=true ;;
+      --jni ) jni=true ;;
       *.jar ) jars="${jars} $1" ;;
       *_JAR ) JARS="${JARS} $1" ;;
       * ) dirs="${dirs} $1" ;;
@@ -107,7 +107,7 @@ JARS=`echo ${JARS}`
     -o -name "[A-Za-z0-9_]*\.glade" -print \
     -o -name "[A-Za-z0-9_]*\.png" -print \
     -o -name "[A-Za-z0-9_]*\.gif" -print \
-    -o -name "[A-Za-z0-9_]*\.xml" -print \
+    -o -name "[A-Za-z0-9_]*\.xml-in" -print \
     -o -path "*dir/[A-Za-z_]*\.[sS]" -print \
     -o -path "*dir/[A-Za-z_]*\.in" -print \
     -o -path "*dir/[A-Za-z_]*\.uu" -print \
@@ -137,6 +137,15 @@ else
     mv files.tmp files.list
 fi
 
+# It is assumed that each file is of the form DIRNAME/BASENAME.SUFFIX,
+# pre-process each into: FILE DIRNAME BASENAME SUFFIX
+
+sed -e 's,^\(\(.*\)/\([^/]*\)\.\([a-zA-Z-]*\)\),\1 \2 \3 \4,' \
+    -e 's,-in$,,' \
+    -e 's,-sh$,,' \
+    < files.list \
+    > files.base
+
 #
 
 echo Creating Makefile.gen from directories ${dirs} ...
@@ -156,23 +165,44 @@ EOF
     echo "$@" 1>&2
 }
 
-# Called as:   set_variable foodir = '$(datadir)/foo'
-# set variable $1 to value $3, if this is the fist time called:
-set_variable ()
+# Does the automake variable exist (as in did this file define it).
+
+automake_variable_defined ()
 {
-    if eval test -z "\${${1}_set:-}"; then
-	eval ${1}_set=true
-	echo "$@"
+    local name=$1
+    local variable=variable_${name}_set
+    eval test -n \"\${${variable}:-}\"
+}
+
+# Called as: variable NAME = [VALUE] or variable NAME += VALUE sets or
+# appends variable $1 to value $3, if this is the fist time called.
+# The only GOT-YA is that all invocations of this function must occure
+# in the same process; which means ``a | while read ... '' can't be
+# used.
+
+automake_variable ()
+{
+    local name=$1 ; shift
+    local op=$1 ; shift
+    if automake_variable_defined $name ; then
+	# Append only; ignore duplicate assigns
+	if test "x$op" = "x+=" ; then
+	    echo "$name" += "$@"
+	fi
+    else
+	local variable=variable_${name}_set
+	eval $variable=\'$name $op "$*"\'
+	echo "$name" = "$@"
     fi
-} 
+}
 
 check_MANS ()
 {
     # bin/ directories require a man page.
     case "$1" in
 	*bindir/* )
-          if test ! -r $1.xml ; then
-	      echo "error: no $(basename $(dirname $1))/$(basename $1).xml man page" 1>&2
+          if test ! -r $1.xml-in ; then
+	      echo "error: no $(basename $(dirname $1))/$(basename $1).xml-in man page" 1>&2
 	      exit 1
 	  fi
 	  ;;
@@ -232,25 +262,28 @@ echo_arch32_PROGRAMS()
 		  ;;
 	    esac
 
-	    echo "if DO_ARCH32_TEST"
 cat <<EOF
+
+if DO_ARCH32_TEST
 ${name_}_SOURCES = ${file}
 # why am_?
 am_${name_}_OBJECTS = ${dir_name}/arch32/${base_name}.\$(OBJEXT)
 ${name_}_LINK = \$(ARCH32_${linker})
 ${dir}32_PROGRAMS += ${dir_name}/arch32/${base_name}
 MOSTLYCLEANFILES += ${dir_name}/arch32/${base_name}.\$(OBJEXT)
-${dir_name}/arch32/${base_name}.\$(OBJEXT): \$(${name_}_SOURCES) frysk/pkglibdir/arch32/\$(am__dirstamp)
-	source='\$<' object='\$@' libtool=no \
-	DEPDIR=\$(DEPDIR) \$(CCDEPMODE) \$(depcomp) \
+# XXX: Re-compile whenever the base .o file chages; avoids getting
+# .deps working.
+${dir_name}/arch32/${base_name}.\$(OBJEXT): ${file}
 	\$(ARCH32_${compiler}) -c -o \$@ $<
+${dir_name}/arch32/${base_name}.\$(OBJEXT): \\
+${dir_name}/${base_name}.\$(OBJEXT) \\
+frysk/pkglibdir/arch32/\$(am__dirstamp)
 EOF
 
 	    if grep pthread.h ${file} > /dev/null 2>&1 ; then
 		echo "${name_}_LDADD = -lpthread"
 	    fi
 	    echo "endif"
-	    echo
             ;;
         * )
             ;;
@@ -283,9 +316,28 @@ echo_LDFLAGS ()
     echo "${name_}_LDFLAGS += \${GEN_GCJ_NO_SIGCHLD_FLAGS}"
 }
 
+# Returns true if the path leads to a java source generator.
+
+has_generated_java_source ()
+{
+    test \
+	-r $1.shenum \
+	-o -r $1.mkenum \
+	-o -r $1.java-sh \
+	-o -r $1.java-in
+}
+
+# Return true if the path leads to either java source, or a java
+# source generator.
+
+has_java_source ()
+{
+    test -r $1.java || has_generated_java_source $1
+}
+	   
 has_java_main ()
 {
-    grep ' main[ ]*[(]' $1 > /dev/null 2>&1
+    grep ' void main[ ]*[(][ ]*String' $1 > /dev/null 2>&1
 }
 
 has_main ()
@@ -402,14 +454,14 @@ print_header "... the lib${GEN_DIRNAME}.a skeleton"
 
 sources=lib${GEN_MAKENAME}_a_SOURCES
 
-cat <<EOF
-
 # Most of the directory's sources will be built into a single archive
 # (.a).  Start with a skeleton for that archive and then accumulate
 # the relevant files.
+automake_variable ${sources} =
+
+cat <<EOF
 
 noinst_LIBRARIES += lib${GEN_DIRNAME}.a
-${sources} =
 if JAR_COMPILE
 ${sources} += ${GEN_DIRNAME}.jar
 endif
@@ -470,10 +522,7 @@ for suffix in .java .java-sh .mkenum .shenum .java-in ; do
 	# source tree - handled earlier.
 	case ${suffix} in
 	    .java)
-		test -r "${d}/${b}.java-sh" && continue
-		test -r "${d}/${b}.mkenum" && continue
-		test -r "${d}/${b}.shenum" && continue
-		test -r "${d}/${b}.java-in" && continue
+		has_generated_java_source ${d}/${b} && continue
 		test -r "common/${b}.java-in" && continue # too strong?
 		test "${b}" = JUnitTests && continue # hack
 		test -r "${d}/${b}.g" && continue
@@ -518,46 +567,46 @@ for suffix in .java-in .java-sh .mkenum .shenum ; do
     done
 done
 
-for suffix in .cxx .c .hxx .s .S .c-sh .c-in .cxx-sh .cxx-in; do
-    print_header "... ${suffix}"
-    grep -e "\\${suffix}\$" files.list | while read file ; do
-	d=`dirname ${file}`
-	b=`basename ${file} ${suffix}`
-	name=${d}/${b}
-	name_=`echo ${name} | sed -e 'y,/-,__,'`
-	s=`echo ${suffix} | sed -e 's/-sh$//' -e 's/-in$//'`
-	if has_main ${file} ; then
-	    echo "${name_}_SOURCES = ${name}${s}"
-	    case "${s}" in
-		.cxx ) echo "${name_}_LINK = \$(CXXLINK)" ;;
-	    esac
-	    echo_PROGRAMS ${name}
-	    check_MANS ${name}
-	    if grep 'pthread\.h' ${file} > /dev/null 2>&1 ; then
-		echo "${name_}_LDADD = -lpthread"
-	    fi
-            # Generate the rules for arch32 test
-	    echo_arch32_PROGRAMS ${name} ${name}${s}
-	else
-	    echo "${sources} += ${file}"
-	fi
-        case "${suffix}" in
-	    *-in | *-sh)
-		echo "BUILT_SOURCES += ${name}${s}"
-		echo "SCRIPT_BUILT += ${name}${s}"
-		;;
-	esac
+generate_compile ()
+{
+    local file=$1
+    local d=$2
+    local b=$3
+    local suffix=$4
+    local sources=$5
+    local name=${d}/${b}
+    local name_=`echo ${name} | sed -e 'y,-/,__,'`
+    if has_main ${file} ; then
+	echo "${name_}_SOURCES = ${name}.${suffix}"
 	case "${suffix}" in
-	    # Hardwire assembler dependency on include/frysk-asm.h;
-	    # automake doesn't generate this :-( FIXME: ARCH-32 case?
-	    .S|.s)
-		echo "${name}.\$(OBJEXT): \$(top_srcdir)/../frysk-imports/include/frysk-asm.h"
-		echo "if DO_ARCH32_TEST"
-		echo "${d}/arch32/${b}.\$(OBJEXT): \$(top_srcdir)/../frysk-imports/include/frysk-asm.h"
-		echo "endif"
+	    cxx ) echo "${name_}_LINK = \$(CXXLINK)" ;;
 	esac
-    done
-done
+	echo_PROGRAMS ${name}
+	check_MANS ${name}
+	if grep 'pthread\.h' ${file} > /dev/null 2>&1 ; then
+	    echo "${name_}_LDADD = -lpthread"
+	fi
+        # Generate the rules for 32-bit compile
+	echo_arch32_PROGRAMS ${name} ${name}.${suffix}
+    else
+	automake_variable ${sources} += ${file}
+    fi
+    case "${file}" in
+	*-in | *-sh)
+	    echo "BUILT_SOURCES += ${name}.${suffix}"
+	    echo "SCRIPT_BUILT += ${name}.${suffix}"
+	    ;;
+    esac
+    case "${file}" in
+	*.S | *.s)
+	    # Hardwire assembler dependency on include/frysk-asm.h;
+	    # automake doesn't generate this :-(
+	    echo "${name}.\$(OBJEXT): \$(top_srcdir)/../frysk-imports/include/frysk-asm.h"
+	    echo "if DO_ARCH32_TEST"
+	    echo "${d}/arch32/${b}.\$(OBJEXT): \$(top_srcdir)/../frysk-imports/include/frysk-asm.h"
+	    echo "endif"
+    esac
+}
 
 # What type of build?
 if $cni ; then
@@ -568,52 +617,71 @@ else
     : default
 fi
 
-# Grep the cni/*.cxx files forming a list of included files.  Assume
-# these are all generated from .class files found in the master .jar.
+# Grep the *.cxx and *.hxx files forming a list of included files.
+# Assume these are all generated from .class files found in the master
+# .jar.
 
-# This matches both:
-# #include "a/file/dot.h"
-# and
-# #define A_FILE "a/file/dot.h"
+generate_cni_header () {
+    local file=$1
+    local d=$2
+    local b=$3
+    local suffix=$4
+    local _file=`echo $file | tr '[/.]' '[__]'`
+    sed -n \
+	-e 's,#include "\(.*\)\.h".*,include - \1,p' \
+	-e 's,#include \([A-Z][A-Z0-9_]*\).*,minclude \1 -,p' \
+	-e 's,#define \([A-Z0-9_]*\) "\(.*\)\.h".*,define \1 \2,p' \
+	< $file > $$.tmp
+    while read action m h j; do
+	echo "# file=$file action=$action m=$m h=$h"
+	if test "$action" = "minclude" ; then
+            # Assume file defining macro depends on this file
+	    automake_variable $m = \$\($_file\)
+	elif has_java_source ${h} ; then
+	    echo "JAVAH_CNI_BUILT += ${h}.h"
+	    echo "CLEANFILES += ${h}.h"
+	    echo "CLEANFILES += ${h}\\\$\$*.h"
+	    j=`echo ${h} | tr '[_]' '[/]'`
+	    echo "${h}.h: $j.java | ${GEN_DIRNAME}.jar"
+	    case $action in
+		include)
+		    case "$suffix" in
+			cxx) echo "$d/$b.o: ${h}.h" ;;
+			hxx) # remember what this file includes
+			    automake_variable $_file += ${h}.h ;;
+		    esac
+		    ;;
+		define)
+		    echo "$d/$b.o: ${h}.h"
+		    # Assume file using this macro is a dependency.
+		    echo "$d/$b.o: \$($m)"
+		    ;;
+	    esac
+	fi
+    done < $$.tmp
+    rm -f $$.tmp
+}
 
-print_header "... *.{hxx,cxx}=.h"
-grep -e '/cni/' -e '/jni/' files.list \
-    | xargs -r grep -H \
-    	-e '#include ".*.h"' \
-        -e '#define [A-Z_]* ".*.h"' \
-    | sed \
-        -e 's/\.\(.\).*:#define [A-Z_]* "/ \1 /' \
-    	-e 's/\.\(.\).*:#include "/ \1 /' \
-    	-e 's/\.h".*$//' \
-    	-e 's/$.*//' \
-    | while read o c h
-do
-  if test \
-      -r ${h}.java -o \
-      -r ${h}.shenum -o \
-      -r ${h}.mkenum -o \
-      -r ${h}.java-sh -o \
-      -r ${h}.java-in \
-      ; then
-      case "$c" in
-	  # Do not know what includes the header; just build early
-	  h)
-	      echo "BUILT_SOURCES += ${h}.h"
-	      echo "JAVAH_BUILT += ${h}.h"
-	      ;;
-	  c) echo "${o}.o: ${h}.h" ;;
-	  esac
-      echo "CLEANFILES += ${h}.h"
-      echo "CLEANFILES += ${h}\\\$\$*.h"
-  fi
-done | sort -u
+# Grep the *.cxx and *.hxx files forming a list of classes that are
+# native.
 
+generate_jnixx_class() {
+    local file=$1
+    local d=$2
+    local b=$3
+    local suffix=$4
+    local j=$(echo $(dirname $dir)/$base)
+    if has_java_source $j ; then
+	automake_variable JNIXX_CLASSES += $(echo $j | tr '[/]' '[.]')
+	echo "${dir}/${base}.o: $j.java"
+    fi
+}
 
-# Generate rules for all .xml files, assume that they are converted to
-# man pages.
+# Generate rules for all .xml-in files, assume that they are converted
+# to man pages.
 
-print_header "... .xml"
-grep -e '\.xml$' files.list | while read xml
+print_header "... .xml-in"
+grep -e '\.xml-in$' files.list | while read xml
 do
   case "$xml" in
       *dir/* )
@@ -632,11 +700,9 @@ do
                   cat <<EOF
 man_MANS += ${d}/${title}.${n}
 CLEANFILES += ${d}/${title}.${n}
-${d}/${title}.${n}: $xml
-	mkdir -p ${d}
-	\$(SUBST_SED) < \$< > \$@.tmp
-	\$(XMLTO) -o ${d} man \$@.tmp
-	rm -f \$@.tmp
+CLEANFILES += ${d}/${title}.xml
+${d}/${title}.xml: $xml
+${d}/${title}.${n}: ${d}/${title}.xml
 EOF
 	  done
 	  ;;
@@ -755,10 +821,9 @@ sed -n -e '/dir\// {
 	    ;;
     esac
     if test -n "${d2}"; then
-	set_variable "${dir}dir" = "\$(${d1}dir)/${d2}"
+	automake_variable "${dir}dir" = "\$(${d1}dir)/${d2}"
     fi
-    set_variable "${dir}_DATA" =
-    echo "${dir}_DATA += $data"
+    automake_variable "${dir}_DATA" += $data
 done
 
 
@@ -781,3 +846,70 @@ EOF
 	printf "\tmv \$@.tmp \$@\n"
     done
 done
+
+
+# Iterate through all the files in file.list; applying all applicable
+# generation rules to each file type.  There are no smarts, each file
+# type gets all operations listed explicitly.
+
+print_header "bulk processing"
+
+while read file dir base suffix ; do
+
+    echo -n "." 1>&2
+
+    echo ""
+    echo "# file=$file"
+    echo "# dir=$dir"
+    echo "# base=$base"
+    echo "# suffix=$suffix"
+    echo ""
+
+    case $file in
+	*/cni/*.cxx | */cni/*.cxx-in | */cni/*.cxx-sh | */cni/*.hxx)
+	    generate_cni_header $file $dir $base $suffix
+	    generate_compile $file $dir $base $suffix ${sources}
+	    ;;
+	*/jni/*.cxx | */jni/*.cxx-in | */jni/*.cxx-sh | */jnixx/*.cxx )
+	    generate_jnixx_class $file $dir $base $suffix
+	    generate_compile $file $dir $base $suffix \
+		lib${GEN_MAKENAME}_jni_a_SOURCES
+	    ;;
+	*.java | *.java-in | *.java-sh )
+	    ;;
+	*.cxx | *.c | *.S | *.cxx-in | *.c-in | *.S-in \
+	    | *.cxx-sh | *.c-sh | *.S-sh )
+	    # Non-cni/jni source.
+	    generate_compile $file $dir $base $suffix ${sources}
+	    ;;
+    esac
+
+done < files.base
+echo "" 1>&2
+
+if automake_variable_defined lib${GEN_MAKENAME}_jni_a_SOURCES ; then
+    cat <<EOF
+noinst_LIBRARIES += lib${GEN_DIRNAME}-jni.a
+lib${GEN_MAKENAME}_jni_so_SOURCES =
+solib_PROGRAMS += lib${GEN_DIRNAME}-jni.so
+lib${GEN_DIRNAME}-jni.so: lib${GEN_DIRNAME}-jni.a
+.PHONY: jni
+jni: lib${GEN_DIRNAME}-jni.so ${GEN_DIRNAME}.jar
+lib${GEN_MAKENAME}_jni_a_SOURCES += jni.cxx
+jnixx_sources = \$(wildcard \$(root_srcdir)/frysk-sys/frysk/jnixx/*.java)
+CLEANFILES += jni.hxx jni.cxx jni.hxx.gch
+\$(lib${GEN_MAKENAME}_jni_a_SOURCES): | jni.hxx jni.hxx.gch
+jni.hxx: \$(jnixx_sources) | ${GEN_DIRNAME}.jar
+	CLASSPATH=\$(GEN_DIRNAME).jar:\$(CLASSPATH) \
+	    \$(JAVA) frysk.jnixx.Main hxx \$(JNIXX_CLASSES) \
+	        > \$@.tmp
+	mv \$@.tmp \$@
+jni.hxx.gch: jni.hxx
+	\$(CXXCOMPILE) -c -x c++-header jni.hxx
+jni.cxx: \$(jnixx_sources) | ${GEN_DIRNAME}.jar jni.hxx.gch
+	CLASSPATH=\$(GEN_DIRNAME).jar:\$(CLASSPATH) \
+	    \$(JAVA) frysk.jnixx.Main cxx \$(JNIXX_CLASSES) \
+	        > \$@.tmp
+	mv \$@.tmp \$@
+EOF
+fi
