@@ -47,7 +47,7 @@ import java.io.InputStreamReader;
 import java.io.IOException;
 import frysk.testbed.TestLib;
 import frysk.testbed.TearDownProcess;
-import frysk.config.Config;
+import frysk.config.Prefix;
 import frysk.sys.DaemonPipePair;
 
 public class TestBreakpoints
@@ -87,7 +87,7 @@ public class TestBreakpoints
     // Create a process that we will communicate with through stdin/out.
     DaemonPipePair process
 	= new DaemonPipePair(new String[] {
-				 Config.getPkgLibFile("funit-breakpoints").getPath()
+				 Prefix.pkgLibFile("funit-breakpoints").getPath()
 			     });
     TearDownProcess.add(process.pid);
     in = new BufferedReader(new InputStreamReader(process.in.getInputStream()));
@@ -213,7 +213,7 @@ public class TestBreakpoints
 
   public void testSteppingtestHitAndRun() throws IOException
   {
-    if (unresolved(4847))
+    if (unresolvedOnIA32(6044))
       return;
 
     installInstructionObserver = true;
@@ -319,7 +319,7 @@ public class TestBreakpoints
 
   public void testSteppingtestInsertRemove() throws IOException
   {
-    if (unresolved(4847))
+    if (unresolvedOnIA32(6044))
       return;
 
     installInstructionObserver = true;
@@ -422,7 +422,7 @@ public class TestBreakpoints
   
   public void testSteppingAddLots() throws IOException
   {
-    if (unresolved(4847))
+    if (unresolvedOnIA32(6044))
       return;
 
     installInstructionObserver = true;
