@@ -45,7 +45,7 @@ import frysk.sys.ProcessIdentifierFactory;
 import frysk.isa.syscalls.Syscall;
 import frysk.isa.syscalls.SyscallTable;
 import frysk.isa.syscalls.SyscallTableFactory;
-import frysk.config.Config;
+import frysk.config.Prefix;
 import java.util.HashMap;
 import java.util.Iterator;
 import java.util.List;
@@ -312,28 +312,6 @@ public class TestTaskSyscallObserver extends TestLib {
 
   };
 
-  public void testCreateAttachedAddSyscallObserver ()
-  {
-    if (unresolved(2915))
-      return;
-
-    int count = 5;
-
-    Manager.host.requestCreateAttachedProc(new String[]
-	{
-	    getExecPath ("funit-syscallloop"),
-	    Integer.toString(count)
-	}, attachedObserver);
-
-    // assertRunUntilStop("run until program exits");
-    assertRunUntilStop("run until program exits");
-
-    assertTrue("enough syscall enter events", syscallObserver1.enter >= count);
-    assertTrue("enough syscall enter exit", syscallObserver1.exit >= count);
-    assertTrue("inSyscall (last call doesn't exit)", syscallObserver1.inSyscall);
-    assertTrue("Caught exec syscall", syscallObserver1.caughtExec);
-  }
-
   /**
    * Test system calls. XXX: How is this different to testSyscallLoop (other
    * than the program run). XXX: Also why is the last syscall expected to exit
@@ -343,7 +321,7 @@ public class TestTaskSyscallObserver extends TestLib {
   {
     // Create program making syscalls
     DaemonBlockedAtEntry child
-	= new DaemonBlockedAtEntry(Config.getPkgLibFile("funit-syscalls"));
+	= new DaemonBlockedAtEntry(Prefix.pkgLibFile("funit-syscalls"));
 
     // Add a syscall observer. XXX: This doesn't work - system
     // call tracing doesn't get enabled enabled.
@@ -416,7 +394,7 @@ public class TestTaskSyscallObserver extends TestLib {
   {
       // Create program making syscalls
       DaemonBlockedAtEntry child
-	  = new DaemonBlockedAtEntry(Config.getPkgLibFile("funit-syscalls"));
+	  = new DaemonBlockedAtEntry(Prefix.pkgLibFile("funit-syscalls"));
       new StopEventLoopWhenProcTerminated(child);
 
     SyscallOpenObserver syscallOpenObserver = new SyscallOpenObserver(
