@@ -41,6 +41,8 @@ package frysk.proc.live;
 
 import frysk.sys.SignalSet;
 import frysk.sys.proc.Status;
+import frysk.isa.watchpoints.WatchpointFunctionFactory;
+import frysk.isa.watchpoints.WatchpointFunctions;
 import frysk.proc.TaskObserver;
 import frysk.proc.Observer;
 import frysk.proc.Observable;
@@ -457,13 +459,21 @@ abstract class LinuxPtraceTaskState extends State {
 	    new StartMainTask("wantToDetach") {
 		LinuxPtraceTaskState handleAttach(LinuxPtraceTask task) {
 		    fine.log("handleAttach", task); 
-		    ((LinuxPtraceProc)task.getProc())
-			.performTaskAttachCompleted(task);
+		    LinuxPtraceProc proc = (LinuxPtraceProc) task.getProc();
+		    // Clear left over breakpoints here. They were
+		    // captured when the Proc was created.
+		    proc.breakpoints.clearAllBreakpoints();
+		    proc.performTaskAttachCompleted(task);
 		    return StartMainTask.wantToAttach;
 		}
 		LinuxPtraceTaskState handleStoppedEvent(LinuxPtraceTask task,
 							Signal signal) {
 		    if (signal == Signal.STOP || signal == Signal.TRAP) {
+		        LinuxPtraceProc proc;
+		        proc = (LinuxPtraceProc) task.getProc();
+		        // Clear left over breakpoints here. They were
+		        // captured when the Proc was created.
+		        proc.breakpoints.clearAllBreakpoints();
 			task.initializeAttachedState();
 			if (task.notifyForkedOffspring() > 0) {
 			    return StartMainTask.detachBlocked;
@@ -723,26 +733,6 @@ abstract class LinuxPtraceTaskState extends State {
 	    this.insyscall = insyscall;
 	}
 	
-	void setupSteppingBreakpoint(LinuxPtraceTask task, long address) {
-	    // Reset pc, this should maybe be moved into the Breakpoint,
-	    // but if the breakpoint gets removed before we step it, and
-	    // the architecture puts the pc just behind the breakpoint
-	    // address, then there is no good other place to get at the
-	    // original pc location.
-	    task.setPC(address);
-
-	    // All logic for determining how and where to step the
-	    // Breakpoint is determined by Proc and
-	    // Breakpoint.prepareStep() (called in sendContinue).
-	    Breakpoint bp = Breakpoint.create(address,((LinuxPtraceProc)task.getProc()));
-	
-	    // TODO: This should really move us to a new TaskState.
-	    // Currently we rely on the Task.steppingBreakpoint
-	    // being set and the Breakpoint/Instruction having all
-	    // the state necessary.
-	    task.steppingBreakpoint = bp;
-	}
-      
         /**
 	 * Tells the LinuxPtraceTask to continue, keeping in kind pending
 	 * breakpoints, with or without syscall tracing.
@@ -889,6 +879,10 @@ abstract class LinuxPtraceTaskState extends State {
 		((TaskObservation) i.next()).delete();
 	    }
 
+	    // Mark this LinuxPtraceTask as just started.  See
+	    // Running.handleTrapped for more explanation.
+	    task.justStartedXXX = true;
+
 	    if (task.notifyExeced() > 0) {
 		return (task.syscallObservers.numberOfObservers() > 0
 			? syscallBlockedInSyscallContinue
@@ -927,7 +921,31 @@ abstract class LinuxPtraceTaskState extends State {
 		return blockedContinue();
 	    return sendContinue(task, Signal.NONE);
 	}
+	
 
+	/**
+	 * Returns the number of blockers if a watchpoint was hit, or -1 when no watchpoint 
+	 * was hit for this Task.
+	 */
+	int checkWatchpoint(LinuxPtraceTask task) {
+	    int blockers = -1;
+	    // First test if this is a watchpoint event.
+	    WatchpointFunctions watchpointFunction = WatchpointFunctionFactory.
+	    	getWatchpointFunctions(task.getISA());
+	    for (int i=0; i<watchpointFunction.getWatchpointCount();  i++) {
+		// Test if a watchpoint has fired
+		if (watchpointFunction.hasWatchpointTriggered(task, i)) {
+		    if (blockers == -1)
+			blockers = 0;
+		    frysk.isa.watchpoints.Watchpoint trigger = watchpointFunction.readWatchpoint(task, i);
+		    blockers += task.notifyWatchpoint(trigger.getAddress(), trigger.getRange(), trigger.isWriteOnly());
+		    watchpointFunction.resetWatchpoint(task, i);
+		}
+	    }
+	    
+	    return blockers;
+	}
+	
 	/**
 	 * Handles traps caused by breakpoints or instruction
 	 * stepping. If there are any Code observers at the address of
@@ -941,9 +959,6 @@ abstract class LinuxPtraceTaskState extends State {
 	 */
 	LinuxPtraceTaskState handleTrappedEvent(LinuxPtraceTask task) {
 	    fine.log("handleTrappedEvent", task);
-	  
-	    Isa isa;
-	    isa = task.getIsaFIXME();
 
 	    // First see if this was just an indication the we stepped.
 	    // And see if we were stepping a breakpoint.  Or whether we
@@ -953,33 +968,48 @@ abstract class LinuxPtraceTaskState extends State {
 	    // first step onto the first instruction of a just started
 	    // task sometimes doesn't set the right task stepped flag.
 	    // So we check and immediately clear here.
+	    Isa isa;
+	    isa = task.getIsaFIXME();
 	    if (isa != null && (isa.isTaskStepped(task) || task.justStartedXXX)) {
 		if (task.justStartedXXX) {
 		    return stepping.handleTrappedEvent(task);
 		} else {
-		    System.err.println("Whoa! Wrong state for stepping: "
-				       + this);
-		    return sendContinue(task, Signal.NONE);
-		}
-	    } else {
-		// Do we have a breakpoint installed here?
-		long address = isa.getBreakpointAddress(task);
-		int blockers = task.notifyCodeBreakpoint(address);
-		if (blockers >= 0) {
-		    // Prepare for stepping the breakpoint
-		    setupSteppingBreakpoint(task, address);
-		  
-		    if (blockers == 0)
-			return sendContinue(task, Signal.NONE);
-		    else
-			return blockedContinue();
-		} else {
-		    // This is not a trap event generated by us.  And we
-		    // also didn't send a step request.  Deliver the
-		    // real Trap event to the Task.
-		    return handleSignaledEvent(task, Signal.TRAP);
+		    throw new RuntimeException("Whoa! Wrong state for stepping: "
+				       	       + this);
 		}
 	    }
+
+	    // Check if a watchpoint triggered.
+	    int blockers = checkWatchpoint(task);
+	    boolean isTrapHandled;
+	    if (blockers != -1)
+	        isTrapHandled = true;
+	    else {
+	        isTrapHandled = false;
+	        blockers = 0;
+	    }
+
+	    // Do we have a breakpoint installed here?
+	    long address = isa.getBreakpointAddress(task);
+	    int stepBlockers = task.notifyCodeBreakpoint(address);
+	    if (stepBlockers >= 0) {
+		// Prepare for stepping the breakpoint
+		blockers += stepBlockers;
+		isTrapHandled = true;
+	    } 
+		
+	    if (!isTrapHandled) 
+		// This is not a trap event generated by us.  And we
+		// also didn't send a step request.  Deliver the
+		// real Trap event to the Task.
+		return handleSignaledEvent(task, Signal.TRAP); 
+	    
+	    // Otherwise return a blocked or continue depending
+	    // on whether something blocked.
+	    if (blockers == 0)
+		return sendContinue(task, Signal.NONE);
+	    else
+		return blockedContinue;		
 	}
 
 	LinuxPtraceTaskState handleAddObservation(LinuxPtraceTask task, TaskObservation observation) {
@@ -1062,11 +1092,21 @@ abstract class LinuxPtraceTaskState extends State {
 	 */
 	LinuxPtraceTaskState handleTrappedEvent(LinuxPtraceTask task) {
 	    fine.log("handleTrappedEvent", task);
-      
+
+	    // First test if this is a watchpoint event.
+	    int blockers = checkWatchpoint(task);
+	    boolean isTrapHandled;
+	    if (blockers != -1)
+	        isTrapHandled = true;
+	    else {
+	        isTrapHandled = false;
+	        blockers = 0;
+	    }
+    
 	    Isa isa;
 	    isa = task.getIsaFIXME();
       
-	    // First see if this was just an indication the we stepped.
+	    // Second, see if this was just an indication the we stepped.
 	    // And see if we were stepping a breakpoint.  Or whether we
 	    // installed a breakpoint at the address.  Otherwise it is a
 	    // real trap event and we should treat it like a trap
@@ -1086,28 +1126,15 @@ abstract class LinuxPtraceTaskState extends State {
 		    task.steppingBreakpoint = null;
 		}
 	  
-		if (task.notifyInstruction() > 0)
-		    return blockedContinue();
-		else
-		    return sendContinue(task, Signal.NONE);
+		blockers += task.notifyInstruction();
+		isTrapHandled = true;
 	    } else {
 		// Do we have a breakpoint installed here?
 		long address = isa.getBreakpointAddress(task);
-		int blockers = task.notifyCodeBreakpoint(address);
-		if (blockers >= 0) {
-		    // Sanity check
-		    if (task.steppingBreakpoint != null)
-			throw new RuntimeException("Already breakpoint stepping: "
-						   + task.steppingBreakpoint);
-	      
-		    // Prepare for stepping the breakpoint
-		    setupSteppingBreakpoint(task, address);
-	      
-		    if (blockers == 0)
-			return sendContinue(task, Signal.NONE);
-		    else
-			return blockedContinue();
-	      
+		int breakpointBlockers = task.notifyCodeBreakpoint(address);
+		if (breakpointBlockers >= 0) {
+		    blockers += breakpointBlockers;
+		    isTrapHandled = true;
 		} else {
 		    // This is not a trap event generated by us.
 	      
@@ -1122,20 +1149,32 @@ abstract class LinuxPtraceTaskState extends State {
 		    // trapping instruction) that we should ignore (this
 		    // would be nice to use to support syscall tracking
 		    // during stepping, but it doesn't happen on all
-		    // architectures).
+		    // architectures). In all these cases a step is actually
+		    // made so we should notify any instruction observers.
 		    if ((task.sigSendXXX != Signal.NONE
 			 || task.syscallSigretXXX
-			 || isa.hasExecutedSpuriousTrap(task)))
-			return sendContinue(task, Signal.NONE);
-	      
-		    // Deliver the real Trap event to the Task.  This is
-		    // somewhat weird, we are either stepping a trapping
-		    // instruction (breakpoint) that we didn't install, or
-		    // something is sending this process an explicit trap
-		    // signal.
-		    return handleSignaledEvent(task, Signal.TRAP);
+			 || isa.hasExecutedSpuriousTrap(task))) {
+			blockers += task.notifyInstruction();
+			isTrapHandled = true;
+		    }
 		}
 	    }
+
+	    if (!isTrapHandled)
+		// Deliver the real Trap event to the Task.  This is
+		// somewhat weird, we are either stepping a trapping
+		// instruction (breakpoint) that we didn't install, or
+		// something is sending this process an explicit trap
+		// signal.
+		return handleSignaledEvent(task, Signal.TRAP);
+
+	    // Otherwise return a blocked or continue depending
+	    // on whether something blocked.
+	    if (blockers == 0)
+		return sendContinue(task, Signal.NONE);
+	    else
+		return blockedContinue;
+
 	}
 
 	private void checkBreakpointStepping(LinuxPtraceTask task) {
