@@ -620,7 +620,7 @@ public class SourceBuffer extends TextBuffer {
     public String getVariable(TextIter iter) {
 	
 	if (this.scope == null || this.scope.getLine() == SourceLocation.UNKNOWN 
-	    || debugInfo == null)
+	    || debugInfo == null) 
 	    return null;
 
 	DOMSource source = this.scope.getLineXXX().getDOMSource();
@@ -633,22 +633,6 @@ public class SourceBuffer extends TextBuffer {
 	if (line == null)
 	    return null;
 
-	DOMTag tag = line.getTag(iter.getLineOffset());
-
-	// No var (or no tag), do nothing
-	if (tag == null || !tag.getType().equals(DOMTagTypes.LOCAL_VAR))
-	    return null;
-
-	Value var;
-	try {
-	    var = debugInfo.print(line.getText().substring(tag.getStart(),
-		    tag.getStart() + tag.getLength()), scope);
-	    if (var == null)
-		return null;
-	} catch (RuntimeException e) {
-	    return null;
-	}
-	
 	return getWordAtIter(iter);
     }
 
@@ -1113,7 +1097,6 @@ public class SourceBuffer extends TextBuffer {
 		String bufferText = loadLines(lines);
 		this.deleteText(this.getStartIter(), this.getEndIter());
 		this.insertText(bufferText);
-		this.createTags();
 		return;
 	    }
 	}
@@ -1128,7 +1111,6 @@ public class SourceBuffer extends TextBuffer {
 
 	this.deleteText(this.getStartIter(), this.getEndIter());
 	this.insertText(bufferText);
-	this.createTags();
     }
 
     public void clear() {
@@ -1199,82 +1181,6 @@ public class SourceBuffer extends TextBuffer {
 	return bufferText;
     }
 
-    /*
-         * Reads through the DOM and creates all the tags necessary
-         */
-    protected void createTags() {
-	DOMSource source = this.scope.getLineXXX().getDOMSource();
-
-	// System.out.println("Creating tags for " +
-        // this.scope.getMethodName());
-	// If there is no source or the parser errored while parsing, return 
-	if (source == null || source.getParserError())
-	    return;
-
-	Iterator lines = source.getLines();
-
-	// Iterate through all the lines
-	while (lines.hasNext()) {
-	    DOMLine line = new DOMLine((Element) lines.next());
-
-	    Iterator tags = line.getTags();
-	    int lineOffset = line.getOffset();
-
-	    // Iterator though all the tags on the line
-	    while (tags.hasNext()) {
-		Element e = (Element) tags.next();
-		DOMTag tag = new DOMTag(e);
-
-		String type = tag.getType();
-
-		// if (type.equals(DOMTagTypes.FUNCTION_BODY))
-		if (type.equals(DOMTagTypes.FUNCTION_CALL)) {
-		    String funcName = tag.getToken();
-
-		    String[] nameArray = funcName.split("\\s*");
-		    StringBuffer buffer = new StringBuffer();
-
-		    for (int i = 0; i < nameArray.length; i++)
-			buffer.append(nameArray[i]);
-
-		    funcName = buffer.toString();
-
-		    this.functions.add(funcName);
-		    this.createMark(funcName, this.getLineIter(line
-			    .getLineNum()), true);
-
-		} else if (type.equals(DOMTagTypes.FUNCTION_BODY)) {
-		} else {
-		    this.applyTag(type, this.getIter(lineOffset
-			    + tag.getStart()), this.getIter(lineOffset
-			    + tag.getStart() + tag.getLength()));
-		}
-	    }
-
-	    Iterator inlines = source.getInlines(line.getLineNum());
-
-	    while (inlines.hasNext()) {
-		DOMInlineInstance func = new DOMInlineInstance(
-			(Element) inlines.next());
-
-		this.applyTag(DOMTagTypes.FUNCTION, this.getIter(lineOffset
-			+ func.getStart()), this.getIter(lineOffset
-			+ func.getStart() + func.getEnd()));
-	    }
-	}// end lines.hasNext()
-
-	// Now iterate through the comments
-	CommentList list = (CommentList) comments.get(source.getFileName());
-
-	while (list != null) {
-	    // this.applyTag(COMMENT_TAG, this.getIter(list.getStartLine(),
-	    // list.getStartCol()),
-	    // this.getIter(list.getEndLine(), list.getEndCol()));
-
-	    list = list.getNextComment();
-	}
-    }
-
     /*
          * Checks whether or not the current search should be restarted by
          * comparing the string last searched with the new string
@@ -1305,20 +1211,21 @@ public class SourceBuffer extends TextBuffer {
     {
 	TextIter startIter = this.getIter(iter.getOffset());
 	// First, we back up iter to a point where there is a non-alphanumeric character
-	while(Character.isLetter(startIter.getChar()) ||
-		Character.isDigit(startIter.getChar())){
+	while(Character.isJavaIdentifierPart(startIter.getChar())) {
 	    startIter.moveBackwardChar();
 	}
+	startIter.moveForwardChar();
+	
+	//Now see if the starting character is valid
+	if (!Character.isJavaIdentifierStart(startIter.getChar()))
+	    return null;
 	
 	// Now, find the end of the word
 	TextIter endIter = this.getIter(iter.getOffset()+1);
-	while(Character.isLetter(endIter.getChar()) ||
-		Character.isDigit(endIter.getChar())) {
+	while(Character.isJavaIdentifierPart(endIter.getChar())) {
 	    endIter.moveForwardChar();
 	}
-	
 	String word = this.getText(startIter, endIter, true);
-	
 	return word.trim();
     }
 
